@@ -9,10 +9,10 @@ use Catmandu::Store::Solr::CQL;
 use Catmandu::Error;
 use Moo;
 
-our $VERSION = "0.02154";
+our $VERSION = "0.03";
 
 with 'Catmandu::Bag';
-with 'Catmandu::Searchable';
+with 'Catmandu::CQLSearchable';
 with 'Catmandu::Buffer';
 
 has cql_mapping => (is => 'ro');
